@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Simple module for creating temporary directories and files
 
@@ -7,7 +6,6 @@ This is a thin wrapper around Pythons tempfile module
 .. versionadded:: 2015.8.0
 
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 import os
