@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Generate Pillar data from Django models through the Django ORM
 
 :maintainer: Micah Hausler <micah.hausler@gmail.com>
@@ -88,21 +87,20 @@ work since the return from values() changes if a ManyToMany is present.
 
 Module Documentation
 ====================
-'''
-from __future__ import absolute_import, print_function, unicode_literals
+"""
 
 import logging
 import os
 import sys
 
 import salt.exceptions
-from salt.ext import six
 import salt.utils.stringutils
 
 HAS_VIRTUALENV = False
 
 try:
     import virtualenv
+
     HAS_VIRTUALENV = True
 except ImportError:
     pass
@@ -111,23 +109,25 @@ log = logging.getLogger(__name__)
 
 
 def __virtual__():
-    '''
+    """
     Always load
-    '''
+    """
     return True
 
 
-def ext_pillar(minion_id,  # pylint: disable=W0613
-               pillar,  # pylint: disable=W0613
-               pillar_name,
-               project_path,
-               settings_module,
-               django_app,
-               env=None,
-               env_file=None,
-               *args,  # pylint: disable=W0613
-               **kwargs):  # pylint: disable=W0613
-    '''
+def ext_pillar(
+    minion_id,  # pylint: disable=W0613
+    pillar,  # pylint: disable=W0613
+    pillar_name,
+    project_path,
+    settings_module,
+    django_app,
+    env=None,
+    env_file=None,
+    *args,  # pylint: disable=W0613
+    **kwargs,
+):  # pylint: disable=W0613
+    """
     Connect to a Django database through the ORM and retrieve model fields
 
     :type pillar_name: str
@@ -150,70 +150,76 @@ def ext_pillar(minion_id,  # pylint: disable=W0613
     :type env_file: str
     :param env_file: An optional bash file that sets up your environment. The
         file is run in a subprocess and the changed variables are then added
-    '''
+    """
 
     if not os.path.isdir(project_path):
-        log.error('Django project dir: \'%s\' not a directory!', project_path)
+        log.error("Django project dir: '%s' not a directory!", project_path)
         return {}
     if HAS_VIRTUALENV and env is not None and os.path.isdir(env):
         for path in virtualenv.path_locations(env):
             if not os.path.isdir(path):
-                log.error('Virtualenv %s not a directory!', path)
+                log.error("Virtualenv %s not a directory!", path)
                 return {}
         # load the virtualenv first
-        sys.path.insert(0,
-                        os.path.join(
-                            virtualenv.path_locations(env)[1],
-                            'site-packages'))
+        sys.path.insert(
+            0, os.path.join(virtualenv.path_locations(env)[1], "site-packages")
+        )
 
     # load the django project
     sys.path.append(project_path)
 
-    os.environ['DJANGO_SETTINGS_MODULE'] = settings_module
+    os.environ["DJANGO_SETTINGS_MODULE"] = settings_module
 
     if env_file is not None:
         import subprocess
 
         base_env = {}
-        proc = subprocess.Popen(['bash', '-c', 'env'], stdout=subprocess.PIPE)
+        proc = subprocess.Popen(["bash", "-c", "env"], stdout=subprocess.PIPE)
         for line in proc.stdout:
-            (key, _, value) = salt.utils.stringutils.to_str(line).partition('=')
+            (key, _, value) = salt.utils.stringutils.to_str(line).partition("=")
             base_env[key] = value
 
-        command = ['bash', '-c', 'source {0} && env'.format(env_file)]
+        command = ["bash", "-c", f"source {env_file} && env"]
         proc = subprocess.Popen(command, stdout=subprocess.PIPE)
 
         for line in proc.stdout:
-            (key, _, value) = salt.utils.stringutils.to_str(line).partition('=')
+            (key, _, value) = salt.utils.stringutils.to_str(line).partition("=")
             # only add a key if it is different or doesn't already exist
             if key not in base_env or base_env[key] != value:
-                os.environ[key] = value.rstrip('\n')
-                log.debug('Adding %s = %s to Django environment', key, value.rstrip('\n'))
+                os.environ[key] = value.rstrip("\n")
+                log.debug(
+                    "Adding %s = %s to Django environment", key, value.rstrip("\n")
+                )
 
     try:
+        # pylint: disable=no-name-in-module
         from django.db.models.loading import get_model
 
+        # pylint: enable=no-name-in-module
+
         django_pillar = {}
 
-        for proj_app, models in six.iteritems(django_app):
-            _, _, app = proj_app.rpartition('.')
+        for proj_app, models in django_app.items():
+            _, _, app = proj_app.rpartition(".")
             django_pillar[app] = {}
-            for model_name, model_meta in six.iteritems(models):
+            for model_name, model_meta in models.items():
                 model_orm = get_model(app, model_name)
                 if model_orm is None:
                     raise salt.exceptions.SaltException(
-                        "Django model '{0}' not found in app '{1}'."
-                        .format(app, model_name))
+                        "Django model '{}' not found in app '{}'.".format(
+                            app, model_name
+                        )
+                    )
 
                 pillar_for_model = django_pillar[app][model_orm.__name__] = {}
 
-                name_field = model_meta['name']
-                fields = model_meta['fields']
+                name_field = model_meta["name"]
+                fields = model_meta["fields"]
 
-                if 'filter' in model_meta:
-                    qs = (model_orm.objects
-                        .filter(**model_meta['filter'])
-                        .values(*fields))
+                if "filter" in model_meta:
+                    qs = model_orm.objects.filter(**model_meta["filter"]).values(
+                        *fields
+                    )
                 else:
                     qs = model_orm.objects.values(*fields)
 
@@ -223,21 +229,23 @@ def ext_pillar(minion_id,  # pylint: disable=W0613
                     # (since we're using it as the key in a dictionary)
                     if name_field not in model:
                         raise salt.exceptions.SaltException(
-                            "Name '{0}' not found in returned fields.".format(
-                                name_field))
+                            f"Name '{name_field}' not found in returned fields."
+                        )
 
                     if model[name_field] in pillar_for_model:
                         raise salt.exceptions.SaltException(
                             "Value for '{0}' is not unique: {0}".format(
-                                model[name_field]))
+                                model[name_field]
+                            )
+                        )
 
                     pillar_for_model[model[name_field]] = model
 
         return {pillar_name: django_pillar}
     except ImportError as e:
-        log.error('Failed to import library: %s', e)
+        log.error("Failed to import library: %s", e)
         return {}
-    except Exception as e:
-        log.error('Failed on Error: %s', e)
-        log.debug('django_orm traceback', exc_info=True)
+    except Exception as e:  # pylint: disable=broad-except
+        log.error("Failed on Error: %s", e)
+        log.debug("django_orm traceback", exc_info=True)
         return {}
