@@ -1,8 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 Proxy Minion interface module for managing VMware ESXi hosts.
 
-.. versionadded:: 2015.8.4
+.. Warning::
+    This module will be deprecated in a future release of Salt. VMware strongly
+    recommends using the
+    `VMware Salt extensions <https://docs.saltproject.io/salt/extensions/salt-ext-modules-vmware/en/latest/all.html>`_
+    instead of the ESXi module. Because the Salt extensions are newer and
+    actively supported by VMware, they are more compatible with current versions
+    of ESXi and they work well with the latest features in the VMware product
+    line.
+
 
 **Special Note: SaltStack thanks** `Adobe Corporation <http://adobe.com/>`_
 **for their support in creating this Proxy Minion integration.**
@@ -270,8 +277,6 @@ for standing up an ESXi host from scratch.
 
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 import os
 
@@ -330,7 +335,7 @@ def init(opts):
     DETAILS["proxytype"] = proxy_conf["proxytype"]
     if ("host" not in proxy_conf) and ("vcenter" not in proxy_conf):
         log.critical(
-            "Neither 'host' nor 'vcenter' keys found in pillar " "for this proxy."
+            "Neither 'host' nor 'vcenter' keys found in pillar for this proxy."
         )
         return False
     if "host" in proxy_conf:
@@ -374,7 +379,7 @@ def init(opts):
 
         if mechanism == "userpass":
             if "username" not in proxy_conf:
-                log.critical("No 'username' key found in pillar for this " "proxy.")
+                log.critical("No 'username' key found in pillar for this proxy.")
                 return False
             if "passwords" not in proxy_conf and len(proxy_conf["passwords"]) > 0:
 
