@@ -6,6 +6,7 @@ For YAML usage information see :ref:`Understanding YAML <yaml>`.
 
 import logging
 import warnings
+from collections import OrderedDict
 
 from yaml.constructor import ConstructorError
 from yaml.parser import ParserError
@@ -15,7 +16,6 @@ import salt.utils.url
 import salt.utils.yamlloader as yamlloader_new
 import salt.utils.yamlloader_old as yamlloader_old
 from salt.exceptions import SaltRenderError
-from salt.utils.odict import OrderedDict
 
 log = logging.getLogger(__name__)
 
