@@ -26,6 +26,7 @@ Install any kind of pkg, dmg or app file on macOS:
 import logging
 import os
 import re
+import shutil
 
 import salt.utils.platform
 from salt.exceptions import CommandExecutionError
@@ -231,6 +232,9 @@ def installed(
     finally:
         if dmg:
             # Unmount to be kind
-            __salt__["macpackage.unmount"](mount_point)
+            out = __salt__["macpackage.unmount"](mount_point)
+            # If unmount succeeded cleanup mount point
+            if out["retcode"] == 0:
+                shutil.rmtree(mount_point)
 
     return ret
