@@ -217,7 +217,7 @@ def query(
             opts = {}
 
     if not backend:
-        backend = opts.get("backend", "tornado")
+        backend = opts.get("backend", "requests")
 
     proxy_host = opts.get("proxy_host", None)
     if proxy_host:
