@@ -11,6 +11,7 @@ import shlex
 import time
 import uuid
 import warnings
+from collections import OrderedDict
 from collections.abc import Hashable
 from functools import wraps
 from xml.dom import minidom
@@ -22,7 +23,6 @@ from jinja2.environment import TemplateModule
 from jinja2.exceptions import TemplateRuntimeError
 from jinja2.ext import Extension
 
-import salt.fileclient
 import salt.utils.data
 import salt.utils.files
 import salt.utils.json
@@ -31,7 +31,6 @@ import salt.utils.url
 import salt.utils.yaml
 from salt.exceptions import TemplateError
 from salt.utils.decorators.jinja import jinja_filter, jinja_global, jinja_test
-from salt.utils.odict import OrderedDict
 from salt.utils.versions import Version
 
 try:
@@ -93,6 +92,8 @@ class SaltCacheLoader(BaseLoader):
             or not hasattr(self._file_client, "opts")
             or self._file_client.opts["file_roots"] != self.opts["file_roots"]
         ):
+            import salt.fileclient
+
             self._file_client = salt.fileclient.get_file_client(
                 self.opts, self.pillar_rend
             )
@@ -239,9 +240,7 @@ class PrintableDict(OrderedDict):
         for key, value in self.items():
             if isinstance(value, str):
                 # keeps quotes around strings
-                # pylint: disable=repr-flag-used-in-string
                 output.append(f"{key!r}: {value!r}")
-                # pylint: enable=repr-flag-used-in-string
             else:
                 # let default output
                 output.append(f"{key!r}: {value!s}")
@@ -252,9 +251,7 @@ class PrintableDict(OrderedDict):
         for key, value in self.items():
             # Raw string formatter required here because this is a repr
             # function.
-            # pylint: disable=repr-flag-used-in-string
             output.append(f"{key!r}: {value!r}")
-            # pylint: enable=repr-flag-used-in-string
         return "{" + ", ".join(output) + "}"
 
 
